==> igniteui-react-charts-18.1.3.tgz: package/esm5/lib/RadialColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { DependencyProperty } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { Point_$type, runOn, markType, markDep, fromEnum } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { ViewportUtils } from "./ViewportUtils";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
/**
 * @hidden
 */
var RadialColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialColumnSeries, _super);
    function RadialColumnSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialColumnSeries.$;
        return _this;
    }
    RadialColumnSeries.prototype.get_di = function () {
        return true;
    };
    RadialColumnSeries.prototype.get_d3 = function () {
        return true;
    };
    RadialColumnSeries.prototype.gw = function () {
        if (!isNaN_(this.gv)) {
            return _super.prototype.gw.call(this);
        }
        return Defaults.h;
    };
    RadialColumnSeries.prototype.bx = function () {
        return new RadialColumnSeriesView(this);
    };
    RadialColumnSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.ub = a;
    };
    RadialColumnSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.ml(false);
    };
    RadialColumnSeries.prototype.l7 = function (a, b, c, d) {
        _super.prototype.l7.call(this, a, b, c, d);
        switch (b) {
            case RadialColumnSeries.$$p[0]:
            case RadialColumnSeries.$$p[1]:
                this.l4();
                break;
        }
    };
    RadialColumnSeries.prototype.preferredCategoryMode = function (a) {
        return a != null && a == this.rp ? 2 : 0;
    };
    RadialColumnSeries.prototype.k0 = function (a, b) {
        _super.prototype.k0.call(this, a, b);
        var c = b;
        if (a) {
            c.c1.count = 0;
        }
    };
    RadialColumnSeries.prototype.get_c2 = function () {
        return true;
    };
    RadialColumnSeries.prototype.gc = function () {
        return this.rp.k3(this.b0.bv, this.b0.bu, this.getEffectiveViewport1(this.b0));
    };
    RadialColumnSeries.prototype.su = function (a, b) {
        _super.prototype.su.call(this, a, b);
        var c = a.f;
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.pv(b);
        var h = this.rw.kz(e, d, f, g);
        var i = b;
        var j = this.rw;
        var k = Math.max(0, 0.5 * j.nl);
        k = Math.max(k, h.minLength * 0.9);
        var l = ViewportUtils.d(k, d, e);
        var m = this.rp.k3(d, e, f);
        var n = Math.max(0.1 * this.rw.nm, k);
        var o = this.rx.d(0, n, d, e);
        var p = this.rx.e(0, n, d, e);
        var q = this.rx.d(m, n, d, e);
        var r = this.rx.e(m, n, d, e);
        var s = Math.sqrt((o - q) * (o - q) + (p - r) * (p - r));
        var t = { $type: Point_$type, x: ViewportUtils.c(0.5, d, e), y: ViewportUtils.f(0.5, d, e) };
        var u = this.s8.count;
        this.r3.a0(this, this.sf(), runOn(this, this.rm), this.sh(b), this.si(b));
        this.r3.r = this.uc;
        this.r3.s = this.ud;
        this.r3.k = this.uc;
        this.r3.l = this.ud;
        var v = false;
        var w = this.r3.b;
        if (w != null) {
            v = true;
        }
        var x = this.rp;
        var y = new ScalerParams(1, b.bv, b.bu, x.cg);
        y.c = this.getEffectiveViewport();
        for (var z = 0; z < c.count; ++z) {
            var aa = Math.min(a.f._inner[z][2], h.maxLength * 1.1);
            var ab = this.rx.d(a.f._inner[z][0], aa, d, e);
            var ac = this.rx.e(a.f._inner[z][0], aa, d, e);
            var ad = Math.sqrt((ab - t.x) * (ab - t.x) + (ac - t.y) * (ac - t.y));
            var ae = ad;
            var af = l;
            if (v) {
                this.tt(c, z, u, x, y, b.q);
            }
            var ag = this.r3.k;
            var ah = this.r3.l;
            var ai = a.f._inner[z][0] - (Math.PI / 2);
            var aj = i.c1.item(z);
            var ak = 0 - (s / 2);
            var al = (s / 2);
            var am = Math.max(af, ae);
            var an = Math.min(af, ae);
            var ao = Math.cos(ai);
            var ap = Math.sin(ai);
            var aq = { $type: Point_$type, x: t.x + (ak * ao - am * ap), y: t.y + (ak * ap + am * ao) };
            var ar = { $type: Point_$type, x: t.x + (al * ao - am * ap), y: t.y + (al * ap + am * ao) };
            var as = { $type: Point_$type, x: t.x + (al * ao - an * ap), y: t.y + (al * ap + an * ao) };
            var at = { $type: Point_$type, x: t.x + (ak * ao - an * ap), y: t.y + (ak * ap + an * ao) };
            var au = new PathGeometry();
            var av = new PathFigure();
            av._startPoint = aq;
            av._isClosed = true;
            var aw = new PolyLineSegment();
            aw._points.add(ar);
            aw._points.add(as);
            aw._points.add(at);
            av._segments.add(aw);
            au.c.add(av);
            aj.ak = au;
            this.r3.ad(aj, false, false, false, false);
        }
        i.c1.count = c.count;
        this.ub.c6();
    };
    RadialColumnSeries.$t = markType(RadialColumnSeries, 'RadialColumnSeries', AnchoredRadialSeries.$);
    RadialColumnSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialColumnSeries, 'raisePropertyChanged', ['RadiusX:uc:ug', [1, 0], 'RadiusY:ud:uh', [1, 0]]);
    return RadialColumnSeries;
}(AnchoredRadialSeries));
export { RadialColumnSeries };
/**
 * @hidden
 */
var RadialColumnSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialColumnSeriesView, _super);
    function RadialColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c1 = null;
        _this.c2 = null;
        _this.c8 = new Path();
        _this.c0 = a;
        _this.c1 = ((function () {
            var $ret = new Pool$1(Path.$);
            $ret.create = runOn(_this, _this.c9);
            $ret.activate = runOn(_this, _this.c3);
            $ret.disactivate = runOn(_this, _this.c5);
            $ret.destroy = runOn(_this, _this.c4);
            return $ret;
        })());
        return _this;
    }
    RadialColumnSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.c2 = new List$1(Path.$, 0);
        if (!this.q) {
            this.cr.qh = Defaults.c;
            this.cr.g1 = Defaults.i;
        }
    };
    RadialColumnSeriesView.prototype.c9 = function () {
        var a = new Path();
        this.c2.add(a);
        a._visibility = 1;
        return a;
    };
    RadialColumnSeriesView.prototype.c3 = function (a) {
        a._visibility = 0;
    };
    RadialColumnSeriesView.prototype.c5 = function (a) {
        a._visibility = 1;
    };
    RadialColumnSeriesView.prototype.c4 = function (a) {
        this.c2.remove(a);
    };
    RadialColumnSeriesView.prototype.c7 = function (a, b, c, d, e, f) {
        this.aq();
    };
    RadialColumnSeriesView.prototype.be = function (a, b) {
        _super.prototype.be.call(this, a, b);
        var c = a;
    };
    RadialColumnSeriesView.prototype.bf = function (a, b) {
        _super.prototype.bf.call(this, a, b);
        var c = a;
    };
    RadialColumnSeriesView.prototype.ac = function (a) {
        return this.c2._inner[a];
    };
    RadialColumnSeriesView.prototype.ab = function (a) {
        var b = this.c2._inner[a];
        this.c8._visibility = b._visibility;
        this.c8.ak = b.ak;
        var c = this.bp(a);
        this.c8._fill = c;
        this.c8._stroke = c;
        this.c8.ac = this.e.fw + 3;
        return this.c8;
    };
    RadialColumnSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c2.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.t(d);
            }
        }
    };
    RadialColumnSeriesView.prototype.al = function (a) {
        var e_1, _a;
        _super.prototype.al.call(this, a);
        var b = 0;
        try {
            for (var _b = __values(fromEnum(this.c1.a)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var c = _c.value;
                this.e.a8.exportPathData(a, c, "column" + b, ["Main", "Fill"]);
                b++;
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    RadialColumnSeriesView.prototype.c6 = function () {
        this.aq();
    };
    RadialColumnSeriesView.$t = markType(RadialColumnSeriesView, 'RadialColumnSeriesView', AnchoredRadialSeriesView.$);
    return RadialColumnSeriesView;
}(AnchoredRadialSeriesView));
export { RadialColumnSeriesView };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/RadialColumnSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends, __values } from "tslib";
import { AnchoredRadialSeries } from "./AnchoredRadialSeries";
import { DependencyProperty } from "igniteui-react-core";
import { Defaults } from "./Defaults";
import { Point_$type, runOn, markType, markDep, fromEnum } from "igniteui-react-core";
import { Pool$1 } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { PathGeometry } from "igniteui-react-core";
import { PathFigure } from "igniteui-react-core";
import { PolyLineSegment } from "igniteui-react-core";
import { ViewportUtils } from "./ViewportUtils";
import { PropertyMetadata } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
import { AnchoredRadialSeriesView } from "./AnchoredRadialSeriesView";
/**
 * @hidden
 */
var RadialColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialColumnSeries, _super);
    function RadialColumnSeries() {
        var _this = _super.call(this) || this;
        _this.ab = RadialColumnSeries.$;
        return _this;
    }
    RadialColumnSeries.prototype.get_dk = function () {
        return true;
    };
    RadialColumnSeries.prototype.get_d5 = function () {
        return true;
    };
    RadialColumnSeries.prototype.gz = function () {
        if (!isNaN_(this.gy)) {
            return _super.prototype.gz.call(this);
        }
        return Defaults.h;
    };
    RadialColumnSeries.prototype.by = function () {
        return new RadialColumnSeriesView(this);
    };
    RadialColumnSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.uf = a;
    };
    RadialColumnSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mn(false);
    };
    RadialColumnSeries.prototype.l9 = function (a, b, c, d) {
        _super.prototype.l9.call(this, a, b, c, d);
        switch (b) {
            case RadialColumnSeries.$$p[0]:
            case RadialColumnSeries.$$p[1]:
                this.l6();
                break;
        }
    };
    RadialColumnSeries.prototype.preferredCategoryMode = function (a) {
        return a != null && a == this.rt ? 2 : 0;
    };
    RadialColumnSeries.prototype.k2 = function (a, b) {
        _super.prototype.k2.call(this, a, b);
        var c = b;
        if (a) {
            c.c1.count = 0;
        }
    };
    RadialColumnSeries.prototype.get_c3 = function () {
        return true;
    };
    RadialColumnSeries.prototype.ge = function () {
        return this.rt.k3(this.b1.bv, this.b1.bu, this.getEffectiveViewport1(this.b1));
    };
    RadialColumnSeries.prototype.sy = function (a, b) {
        _super.prototype.sy.call(this, a, b);
        var c = a.f;
        var d = b.bv;
        var e = b.bu;
        var f = this.getEffectiveViewport1(b);
        var g = this.pz(b);
        var h = this.r0.k0(e, d, f, g);
        var i = b;
        var j = this.r0;
        var k = Math.max(0, 0.5 * j.nm);
        k = Math.max(k, h.minLength * 0.9);
        var l = ViewportUtils.d(k, d, e);
        var m = this.rt.k3(d, e, f);
        var n = Math.max(0.1 * this.r0.nn, k);
        var o = this.r1.d(0, n, d, e);
        var p = this.r1.e(0, n, d, e);
        var q = this.r1.d(m, n, d, e);
        var r = this.r1.e(m, n, d, e);
        var s = Math.sqrt((o - q) * (o - q) + (p - r) * (p - r));
        var t = { $type: Point_$type, x: ViewportUtils.c(0.5, d, e), y: ViewportUtils.f(0.5, d, e) };
        var u = this.tc.count;
        this.r7.a2(this, this.sj(), runOn(this, this.rq), this.sl(b), this.sm(b));
        this.r7.r = this.ug;
        this.r7.s = this.uh;
        this.r7.k = this.ug;
        this.r7.l = this.uh;
        var v = false;
        var w = this.r7.b;
        if (w != null) {
            v = true;
        }
        var x = this.rt;
        var y = new ScalerParams(1, b.bv, b.bu, x.cg);
        y.c = this.getEffectiveViewport();
        for (var z = 0; z < c.count; ++z) {
            var aa = Math.min(a.f._inner[z][2], h.maxLength * 1.1);
            var ab = this.r1.d(a.f._inner[z][0], aa, d, e);
            var ac = this.r1.e(a.f._inner[z][0], aa, d, e);
            var ad = Math.sqrt((ab - t.x) * (ab - t.x) + (ac - t.y) * (ac - t.y));
            var ae = ad;
            var af = l;
            if (v) {
                this.tx(c, z, u, x, y, b.q);
            }
            var ag = this.r7.k;
            var ah = this.r7.l;
            var ai = a.f._inner[z][0] - (Math.PI / 2);
            var aj = i.c1.item(z);
            var ak = 0 - (s / 2);
            var al = (s / 2);
            var am = Math.max(af, ae);
            var an = Math.min(af, ae);
            var ao = Math.cos(ai);
            var ap = Math.sin(ai);
            var aq = { $type: Point_$type, x: t.x + (ak * ao - am * ap), y: t.y + (ak * ap + am * ao) };
            var ar = { $type: Point_$type, x: t.x + (al * ao - am * ap), y: t.y + (al * ap + am * ao) };
            var as = { $type: Point_$type, x: t.x + (al * ao - an * ap), y: t.y + (al * ap + an * ao) };
            var at = { $type: Point_$type, x: t.x + (ak * ao - an * ap), y: t.y + (ak * ap + an * ao) };
            var au = new PathGeometry();
            var av = new PathFigure();
            av._startPoint = aq;
            av._isClosed = true;
            var aw = new PolyLineSegment();
            aw._points.add(ar);
            aw._points.add(as);
            aw._points.add(at);
            av._segments.add(aw);
            au.c.add(av);
            aj.an = au;
            this.r7.ad(aj, false, false, false, false);
        }
        i.c1.count = c.count;
        this.uf.c6();
    };
    RadialColumnSeries.$t = markType(RadialColumnSeries, 'RadialColumnSeries', AnchoredRadialSeries.$);
    RadialColumnSeries.$$p = markDep(DependencyProperty, PropertyMetadata, RadialColumnSeries, 'raisePropertyChanged', ['RadiusX:ug:uk', [1, 0], 'RadiusY:uh:ul', [1, 0]]);
    return RadialColumnSeries;
}(AnchoredRadialSeries));
export { RadialColumnSeries };
/**
 * @hidden
 */
var RadialColumnSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialColumnSeriesView, _super);
    function RadialColumnSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c0 = null;
        _this.c1 = null;
        _this.c2 = null;
        _this.c8 = new Path();
        _this.c0 = a;
        _this.c1 = ((function () {
            var $ret = new Pool$1(Path.$);
            $ret.create = runOn(_this, _this.c9);
            $ret.activate = runOn(_this, _this.c3);
            $ret.disactivate = runOn(_this, _this.c5);
            $ret.destroy = runOn(_this, _this.c4);
            return $ret;
        })());
        return _this;
    }
    RadialColumnSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        this.c2 = new List$1(Path.$, 0);
        if (!this.q) {
            this.cr.ql = Defaults.c;
            this.cr.g4 = Defaults.i;
        }
    };
    RadialColumnSeriesView.prototype.c9 = function () {
        var a = new Path();
        this.c2.add(a);
        a._visibility = 1;
        return a;
    };
    RadialColumnSeriesView.prototype.c3 = function (a) {
        a._visibility = 0;
    };
    RadialColumnSeriesView.prototype.c5 = function (a) {
        a._visibility = 1;
    };
    RadialColumnSeriesView.prototype.c4 = function (a) {
        this.c2.remove(a);
    };
    RadialColumnSeriesView.prototype.c7 = function (a, b, c, d, e, f) {
        this.aq();
    };
    RadialColumnSeriesView.prototype.be = function (a, b) {
        _super.prototype.be.call(this, a, b);
        var c = a;
    };
    RadialColumnSeriesView.prototype.bf = function (a, b) {
        _super.prototype.bf.call(this, a, b);
        var c = a;
    };
    RadialColumnSeriesView.prototype.ac = function (a) {
        return this.c2._inner[a];
    };
    RadialColumnSeriesView.prototype.ab = function (a) {
        var b = this.c2._inner[a];
        this.c8._visibility = b._visibility;
        this.c8.an = b.an;
        var c = this.bp(a);
        this.c8._fill = c;
        this.c8._stroke = c;
        this.c8.ad = this.e.fy + 3;
        return this.c8;
    };
    RadialColumnSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            for (var c = 0; c < this.c2.count; c++) {
                var d = this.aa(c, b);
                this.bd(d, c, b);
                a.t(d);
            }
        }
    };
    RadialColumnSeriesView.prototype.al = function (a) {
        var e_1, _a;
        _super.prototype.al.call(this, a);
        var b = 0;
        try {
            for (var _b = __values(fromEnum(this.c1.a)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var c = _c.value;
                this.e.a9.exportPathData(a, c, "column" + b, ["Main", "Fill"]);
                b++;
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    RadialColumnSeriesView.prototype.c6 = function () {
        this.aq();
    };
    RadialColumnSeriesView.$t = markType(RadialColumnSeriesView, 'RadialColumnSeriesView', AnchoredRadialSeriesView.$);
    return RadialColumnSeriesView;
}(AnchoredRadialSeriesView));
export { RadialColumnSeriesView };
